package com.yourkit.probes.builtin;

import com.yourkit.probes.StringColumn;
import com.yourkit.probes.Table;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

/**
 * This class is not a probe class itself nor contains probe classes.
 * Instead, it provides a utility method to store arbitrary text messages.
 * They will be shown in "Probes" tab as "Messages".
 */
public final class Messages {
  private static final class MessageTable extends Table {
    private final StringColumn myCategory = new StringColumn("Category");
    private final StringColumn myMessage = new StringColumn("Message");
    private final StringColumn myDetail = new StringColumn("Detail");

    public MessageTable() {
      super("Messages", Table.MASK_FOR_POINT_EVENTS);
    }
  }
  private static final MessageTable T_MESSAGE = new MessageTable();

  /**
   * @param category free text description of message category,
   *    which can be used to filtering messages of different origin; must not be {@code null}
   * @param message free text; must not be {@code null}
   * @param detail additional description of the message; pass {@code null} for no description
   */
  public static void message(
    @NotNull final String category,
    @NotNull final String message,
    @Nullable final String detail
  ) {
    final int rowIndex = T_MESSAGE.createRow();
    T_MESSAGE.myCategory.setValue(rowIndex, category);
    T_MESSAGE.myMessage.setValue(rowIndex, message);
    T_MESSAGE.myDetail.setValue(rowIndex, detail != null ? detail : "");
  }
}
